# ![Image](./GhostEye.png "GhostEye") physical_sources

To determine the acoustic levels at some distance from the source of the acoustic signal you must be able to represent 
the levels in some manner. The collection of code represent three types of source descriptions:
+ Analytic sources - sources that are described some an equation of some sort
+ Point sources - these are a single spectral, or set of spectral representations that can be queried with a coordinate representation
+ Spherical sources - the data is arranged around the source of the acoustic signals in a sphere with a fixed radius.

